@@ -1,9 +1,11 @@
 """
 Tools for helping to test Twisted applications.
 """
-from __future__ import absolute_import
-
 from pprint import pformat
+from typing import Union, Sequence, Callable
+from unittest import TestCase
+
+from constantly import NamedConstant
 
 from . import compare
 from twisted.logger import globalLogPublisher, formatEvent, LogLevel
@@ -22,7 +24,7 @@ class LogCapture(object):
       otherwise they will be a tuple of the specified fields.
     """
 
-    def __init__(self, fields=('log_level', formatEvent,)):
+    def __init__(self, fields: Sequence[Union[str, Callable]] = ('log_level', formatEvent,)):
         #: The list of events captured.
         self.events = []
         self.fields = fields
@@ -39,7 +41,7 @@ class LogCapture(object):
         "Stop capturing."
         globalLogPublisher._observers = self.original_observers
 
-    def check(self, *expected, **kw):
+    def check(self, *expected, order_matters: bool = True):
         """
         Check captured events against those supplied. Please see the ``fields`` parameter
         to the constructor to see how "actual" events are built.
@@ -48,8 +50,6 @@ class LogCapture(object):
           This defaults to ``True``. If ``False``, the order of expected logging versus
           actual logging will be ignored.
         """
-        order_matters = kw.pop('order_matters', True)
-        assert not kw, 'order_matters is the only keyword parameter'
         actual = []
         for event in self.events:
             actual_event = tuple(field(event) if callable(field) else event.get(field)
@@ -78,9 +78,9 @@ class LogCapture(object):
                     'other entries:\n%s'
                 ) % (pformat(matched), pformat(expected), pformat(unmatched)))
 
-    def check_failure_text(self, expected, index=-1, attribute='value'):
+    def check_failure_text(self, expected: str, index: int = -1, attribute: str = 'value'):
         """
-        Check the string representation of an attribute of a logged :class:`Failure` is as expected.
+        Check the string representation of an attribute of a logged ``Failure`` is as expected.
 
         :param expected: The expected string representation.
         :param index: The index into :attr:`events` where the failure should have been logged.
@@ -88,7 +88,7 @@ class LogCapture(object):
         """
         compare(expected, actual=str(getattr(self.events[index]['log_failure'], attribute)))
 
-    def raise_logged_failure(self, start_index=0):
+    def raise_logged_failure(self, start_index: int = 0):
         """
         A debugging tool that raises the first failure encountered in captured logging.
 
@@ -100,7 +100,7 @@ class LogCapture(object):
                 raise failure
 
     @classmethod
-    def make(cls, testcase, **kw):
+    def make(cls, testcase: TestCase, **kw):
         """
         Instantiate, install and add a cleanup for a :class:`LogCapture`.
 
@@ -115,12 +115,12 @@ class LogCapture(object):
 
 
 #: Short reference to Twisted's ``LogLevel.debug``
-DEBUG = LogLevel.debug
+DEBUG: NamedConstant = LogLevel.debug
 #: Short reference to Twisted's ``LogLevel.info``
-INFO = LogLevel.info
+INFO: NamedConstant = LogLevel.info
 #: Short reference to Twisted's ``LogLevel.warn``
-WARN = LogLevel.warn
+WARN: NamedConstant = LogLevel.warn
 #: Short reference to Twisted's ``LogLevel.error``
-ERROR = LogLevel.error
+ERROR: NamedConstant = LogLevel.error
 #: Short reference to Twisted's ``LogLevel.critical``
-CRITICAL = LogLevel.critical
+CRITICAL: NamedConstant = LogLevel.critical
